@@ -1,34 +1,17 @@
 ##
-# This software was developed and / or modified by Raytheon Company,
-# pursuant to Contract DG133W-05-CQ-1067 with the US Government.
-# 
-# U.S. EXPORT CONTROLLED TECHNICAL DATA
-# This software product contains export-restricted data whose
-# export/transfer/disclosure is restricted by U.S. law. Dissemination
-# to non-U.S. persons whether in the United States or abroad requires
-# an export license or other authorization.
-#
-# Contractor Name:        Raytheon Company
-# Contractor Address:     6825 Pine Street, Suite 340
-#                         Mail Stop B8
-#                         Omaha, NE 68106
-#                         402.291.0100
-# 
-# See the AWIPS II Master Rights File ("Master Rights File.pdf") for
-# further licensing information.
 ##
 
 from string import Template
 
 import ctypes
-import stomp
+from . import stomp
 import socket
 import sys
 import time
 import threading
 import xml.etree.ElementTree as ET
 
-import ThriftClient
+from . import ThriftClient
 from dynamicserialize.dstypes.com.raytheon.uf.common.alertviz import AlertVizRequest
 from dynamicserialize import DynamicSerializationManager
 
@@ -47,6 +30,8 @@ from dynamicserialize import DynamicSerializationManager
 #    01/07/11        5645          cjeanbap       Added audio file to Status Message.
 #    05/27/11        3050          cjeanbap       Added if-statement to check Priority
 #                                                 value
+#    07/27/15        4654          skorolev       Added filters
+#    11/11/15        5120          rferrel        Cannot serialize empty filters.
 #
 class NotificationMessage:
 
@@ -58,13 +43,14 @@ class NotificationMessage:
              4: 'EVENTB',
              5: 'VERBOSE'}
 
-   def __init__(self, host='localhost', port=61999, message='', priority='PROBLEM', category="LOCAL", source="ANNOUNCER", audioFile="NONE"):
+   def __init__(self, host='localhost', port=61999, message='', priority='PROBLEM', category="LOCAL", source="ANNOUNCER", audioFile="NONE", filters=None):
       self.host = host
       self.port = port
       self.message = message
       self.audioFile = audioFile
       self.source = source
       self.category = category
+      self.filters = filters
 
       priorityInt = None
 
@@ -89,8 +75,8 @@ class NotificationMessage:
               priorityInt = int(5)
 
       if (priorityInt < 0 or priorityInt > 5):
-          print "Error occurred, supplied an invalid Priority value: " + str(priorityInt)
-          print "Priority values are 0, 1, 2, 3, 4 and 5."
+          print("Error occurred, supplied an invalid Priority value: " + str(priorityInt))
+          print("Priority values are 0, 1, 2, 3, 4 and 5.")
           sys.exit(1)
 
       if priorityInt is not None:
@@ -100,8 +86,8 @@ class NotificationMessage:
 
    def connection_timeout(self, connection):
           if (connection is not None and not connection.is_connected()):
-              print "Connection Retry Timeout"
-              for tid, tobj in threading._active.items():
+              print("Connection Retry Timeout")
+              for tid, tobj in list(threading._active.items()):
                   if tobj.name is "MainThread":
                       res = ctypes.pythonapi.PyThreadState_SetAsyncExc(tid, ctypes.py_object(SystemExit))
                       if res != 0 and res != 1:
@@ -113,9 +99,9 @@ class NotificationMessage:
        # of the message to AlertViz
        # 9581 is global distribution thru ThriftClient to Edex
        # 61999 is local distribution
-    if (self.port == 61999):
+    if (int(self.port) == 61999):
         # use stomp.py
-        conn = stomp.Connection(host_and_ports=[(self.host, self.port)])
+        conn = stomp.Connection(host_and_ports=[(self.host, 61999)])
         timeout = threading.Timer(5.0, self.connection_timeout, [conn])
 
         try:
@@ -132,6 +118,8 @@ class NotificationMessage:
         sm.set("category", self.category)
         sm.set("sourceKey", self.source)
         sm.set("audioFile", self.audioFile)
+        if self.filters is not None and len(self.filters) > 0:
+            sm.set("filters", self.filters)
         msg = ET.SubElement(sm, "message")
         msg.text = self.message
         details = ET.SubElement(sm, "details")
@@ -144,22 +132,22 @@ class NotificationMessage:
             conn.stop()
     else:
         # use ThriftClient
-        alertVizRequest = createRequest(self.message, self.priority, self.source, self.category, self.audioFile)
+        alertVizRequest = createRequest(self.message, self.priority, self.source, self.category, self.audioFile, self.filters)
         thriftClient = ThriftClient.ThriftClient(self.host, self.port, "/services")
 
         serverResponse = None
         try:
             serverResponse = thriftClient.sendRequest(alertVizRequest)
-        except Exception, ex:
-            print "Caught exception submitting AlertVizRequest: ", str(ex)
+        except Exception as ex:
+            print("Caught exception submitting AlertVizRequest: ", str(ex))
 
         if (serverResponse != "None"):
-            print "Error occurred submitting Notification Message to AlertViz receiver: ", serverResponse
+            print("Error occurred submitting Notification Message to AlertViz receiver: ", serverResponse)
             sys.exit(1)
         else:
-            print "Response: " + str(serverResponse)
+            print("Response: " + str(serverResponse))
 
-def createRequest(message, priority, source, category, audioFile):
+def createRequest(message, priority, source, category, audioFile, filters):
     obj = AlertVizRequest()
 
     obj.setMachine(socket.gethostname())
@@ -171,7 +159,7 @@ def createRequest(message, priority, source, category, audioFile):
         obj.setAudioFile(audioFile)
     else:
         obj.setAudioFile('\0')
-
+    obj.setFilters(filters)
     return obj
 
 if __name__ == '__main__':
