@@ -1,21 +1,4 @@
 ##
-# This software was developed and / or modified by Raytheon Company,
-# pursuant to Contract DG133W-05-CQ-1067 with the US Government.
-#
-# U.S. EXPORT CONTROLLED TECHNICAL DATA
-# This software product contains export-restricted data whose
-# export/transfer/disclosure is restricted by U.S. law. Dissemination
-# to non-U.S. persons whether in the United States or abroad requires
-# an export license or other authorization.
-#
-# Contractor Name:        Raytheon Company
-# Contractor Address:     6825 Pine Street, Suite 340
-#                         Mail Stop B8
-#                         Omaha, NE 68106
-#                         402.291.0100
-#
-# See the AWIPS II Master Rights File ("Master Rights File.pdf") for
-# further licensing information.
 ##
 
 #
@@ -35,7 +18,7 @@
 import qpid
 import zlib
 
-from Queue import Empty
+from queue import Empty
 from qpid.exceptions import Closed
 
 class QpidSubscriber:
@@ -56,7 +39,7 @@ class QpidSubscriber:
         if (topicName == 'edex.alerts'):
             self.decompress = True
 
-        print "Establishing connection to broker on", self.host
+        print("Establishing connection to broker on", self.host)
         queueName = topicName + self.__session.name
         self.__session.queue_declare(queue=queueName, exclusive=True, auto_delete=True, arguments={'qpid.max_count':100, 'qpid.policy_type':'ring'})
         self.__session.exchange_bind(exchange='amq.topic', queue=queueName, binding_key=topicName)
@@ -67,7 +50,7 @@ class QpidSubscriber:
         queue = self.__session.incoming(local_queue_name)
         self.__session.message_subscribe(serverQueueName, destination=local_queue_name)
         queue.start()
-        print "Connection complete to broker on", self.host
+        print("Connection complete to broker on", self.host)
 
         while self.subscribed:
             try:
@@ -75,7 +58,7 @@ class QpidSubscriber:
                 content = message.body
                 self.__session.message_accept(qpid.datatypes.RangedSet(message.id))
                 if (self.decompress):
-                    print "Decompressing received content"
+                    print("Decompressing received content")
                     try:
                         # http://stackoverflow.com/questions/2423866/python-decompressing-gzip-chunk-by-chunk
                         d = zlib.decompressobj(16+zlib.MAX_WBITS)
